pub struct MessageCommandGroupBuilder<State>where
State: StateBound,{ /* private fields */ }Expand description
A message command group builder, which allows setting extra metadata.
Implementations
Sourceimpl<State> MessageCommandGroupBuilder<State>where
State: StateBound,
impl<State> MessageCommandGroupBuilder<State>where
State: StateBound,
Sourcepub fn command(self, command: impl Into<MessageCommand<State>>) -> Self
pub fn command(self, command: impl Into<MessageCommand<State>>) -> Self
Adds a command to the group.
Arguments:
command- The command to add to the command group.
Returns:
MessageCommandGroupBuilder - The current builder, with the command set.
Sourcepub fn nest(self, group: impl Into<MessageCommandGroup<State>>) -> Self
pub fn nest(self, group: impl Into<MessageCommandGroup<State>>) -> Self
Nests a group into this group.
Arguments:
group- The group to nest.
Returns:
MessageCommandGroupBuilder - The current builder with the nested group.
Sourcepub fn on_error<Error>(
self,
handler: impl ErrorHandler<State, Error> + 'static,
) -> Self
pub fn on_error<Error>( self, handler: impl ErrorHandler<State, Error> + 'static, ) -> Self
Adds an error handler scoped to this message command group.
Arguments:
handler- The error handler function.
Returns:
MessageCommandGroupBuilder - The current builder with the error handler added.