pub struct Command;Expand description
A unified API to build commands.
This type’s associated functions initialize specialized command types depending on what type is being initialized. This type does not represent a command directly.
Implementations
Sourceimpl Command
impl Command
Sourcepub fn prefixed<State, F, Args>(
name: impl Into<String>,
handler: F,
) -> PrefixedCommandBuilder<State>where
F: PrefixedCommandHandler<State, Args> + 'static,
Args: Send + Sync + 'static,
State: StateBound,
pub fn prefixed<State, F, Args>(
name: impl Into<String>,
handler: F,
) -> PrefixedCommandBuilder<State>where
F: PrefixedCommandHandler<State, Args> + 'static,
Args: Send + Sync + 'static,
State: StateBound,
Creates a new prefixed command builder with the given name and handler.
Arguments:
name- The command’s name, used to invoke the command.handler- The command’s handler, the function that executes when the command is run.
Returns:
PrefixedCommandBuilder - A new command builder with the given name and handler.
Sourcepub fn slash<State, F, Args>(
name: impl Into<String>,
handler: F,
) -> SlashCommandBuilder<State>where
F: SlashCommandHandler<State, Args> + 'static,
State: StateBound,
Args: Send + Sync + 'static,
pub fn slash<State, F, Args>(
name: impl Into<String>,
handler: F,
) -> SlashCommandBuilder<State>where
F: SlashCommandHandler<State, Args> + 'static,
State: StateBound,
Args: Send + Sync + 'static,
Creates a new slash command builder with the given name and handler.
Arguments:
name- The command’s name, used to invoke the command.handler- The command’s handler, the function that executes when the command is run.
Returns:
SlashCommandBuilder - A new slash command builder with the given name.